@@ -14,17 +14,18 @@
 
 
 .isNativeDriver <- function(d) {
-	return ( (d %in% .nativeDrivers() ) )
+	return( d %in% .nativeDrivers() ) 
 }
 
+
 writeFormats <- function() {
 	if ( .requireRgdal(FALSE) ) {
 		gd <- .gdalWriteFormats() 
-		short <- c(.nativeDrivers(),  'ascii', as.vector(gd[,1]))
-		long <- c(.nativeDriversLong(), 'Arc ASCII', as.vector(gd[,2]))
+		short <- c(.nativeDrivers(),  'ascii', 'CDF', 'big', as.vector(gd[,1]))
+		long <- c(.nativeDriversLong(), 'Arc ASCII', 'NetCDF', 'big.matrix', as.vector(gd[,2]))
 	} else {
-		short <- c(.nativeDrivers(), 'ascii', 'CDF', "")
-		long <- c(.nativeDriversLong(), "Arc ASCII", "netCDF / CF", "rgdal not installed")
+		short <- c(.nativeDrivers(), 'ascii', 'CDF', 'big', "")
+		long <- c(.nativeDriversLong(), "Arc ASCII", "NetCDF", "big.matrix", "", "rgdal not installed")
 	}
 	
 	m <- cbind(short, long)
