@@ -47,7 +47,7 @@ function(x, y, fun=NULL, na.rm=FALSE, cellnumbers=FALSE, df=FALSE, layer, nl, fa
 	rr <- raster(x)
 	cn <- names(x)
 	
-	pb <- pbCreate(nlns, ...)
+	pb <- pbCreate(nlns, label='extract', ...)
 	
 	
 	if (.doCluster()) {
@@ -57,8 +57,8 @@ function(x, y, fun=NULL, na.rm=FALSE, cellnumbers=FALSE, df=FALSE, layer, nl, fa
 		cat('Using cluster with', nodes, 'nodes\n')
 		flush.console()
 
-		clFun <- function(i) {
-			pp <- y[i,]
+		clusterExport(cl, c('rsbb', 'rr', 'addres', 'cellnumbers'), envir=environment())
+		clFun <- function(i, pp) {
 			spbb <- bbox(pp)
 			if (! (spbb[1,1] > rsbb[1,2] | spbb[1,2] < rsbb[1,1] | spbb[2,1] > rsbb[2,2] | spbb[2,2] < rsbb[2,1]) ) {
 				rc <- crop(rr, extent(pp)+addres)
@@ -78,7 +78,7 @@ function(x, y, fun=NULL, na.rm=FALSE, cellnumbers=FALSE, df=FALSE, layer, nl, fa
 		}
 		
         for (ni in 1:nodes) {
-			sendCall(cl[[ni]], clFun, ni, tag=ni)
+			sendCall(cl[[ni]], clFun, list(ni, y[ni,]), tag=ni)
 		}
 		
 		for (i in 1:nlns) {
@@ -89,7 +89,7 @@ function(x, y, fun=NULL, na.rm=FALSE, cellnumbers=FALSE, df=FALSE, layer, nl, fa
 			res[[d$value$tag]] <- d$value$value
 			ni <- ni + 1
 			if (ni <= nlns) {
-				sendCall(cl[[d$node]], clFun, ni, tag=ni)
+				sendCall(cl[[d$node]], clFun, list(ni, y[ni,]), tag=ni)
 			}
 			pbStep(pb)
 		}	
