@@ -1,4 +1,4 @@
-# Author: Robert J. Hijmans, r.hijmans@gmail.com
+# Author: Robert J. Hijmans
 # Date : December 2009
 # Version 0.9
 # Licence GPL v3
@@ -25,12 +25,13 @@ function(x, y, fun=NULL, na.rm=FALSE, weights=FALSE, cellnumbers=FALSE, small=FA
 
 	if (!is.null(fun)) {
 		cellnumbers <- FALSE
-	} else if (weights) {
-		if (!is.null(fun)) {
-			test <- try(slot(fun, 'generic') == 'mean', silent=TRUE)
-			if (!isTRUE(test)) {
-				warning('"fun" was changed to "mean"; other functions cannot be used when "weights=TRUE"' )
-			}
+	    if (weights) {
+			if (!is.null(fun)) {
+				test <- try(slot(fun, 'generic') == 'mean', silent=TRUE)
+				if (!isTRUE(test)) {
+					warning('"fun" was changed to "mean"; other functions cannot be used when "weights=TRUE"' )
+				}
+			}	
 		}
 	}
 	
@@ -258,16 +259,21 @@ function(x, y, fun=NULL, na.rm=FALSE, weights=FALSE, cellnumbers=FALSE, small=FA
 		}		
 
 		lyrs <- layer:(layer+nl-1)
-		colnames(res) <- c('ID', names(x)[lyrs])
+		if (cellnumbers) {
+			colnames(res) <- c('ID', 'cell', names(x)[lyrs])
+		} else {
+			colnames(res) <- c('ID', names(x)[lyrs])
+		}
 		
 		if (any(is.factor(x)) & factors) {
-			v <- res[, -1, drop=FALSE]
+			i <- ifelse(cellnumbers, 1:2, 1)
+			v <- res[, -i, drop=FALSE]
 			if (ncol(v) == 1) {
 				v <- data.frame(factorValues(x, v[,1], layer))
 			} else {
 				v <- .insertFacts(x, v, lyrs)
 			}
-			res <- data.frame(res[,1,drop=FALSE], v)
+			res <- data.frame(res[,i,drop=FALSE], v)
 		}
 	}
 
