@@ -58,13 +58,8 @@
 	
 	points <- .pointsToMatrix(xy)
 
-	pvals <- .getPutVals(xy, field, nrow(points), mask)
-	field <- pvals[,1]
-	if (ncol(pvals) > 1) {
-		rs@data@isfactor <- TRUE
-		rs@data@attributes <- list(pvals)
-	}
-	
+	field <- .getPutVals(xy, field, nrow(points), mask)
+
 	xy <- points
 	
 	nres <- max(length(fun(1)), length(fun(1:5)))
@@ -77,7 +72,7 @@
 		if (is.atomic(field) & length(field)==1) {
 			field <- rep(field, dim(xy)[1])
 		}
-		if (dim(xy)[1] != length(field)) {
+		if (nrow(xy) != NROW(field)) {
 			stop('number of points does not match the number of fields')
 		}
 	}
@@ -128,11 +123,11 @@
 					cells <- as.numeric(v[,1])
 					d[cells, ] <- as.matrix(v)[,-1]
 				} else {
-					v = tapply(ss[,5], ss[,4], fun, na.rm=na.rm)
+					v <- tapply(ss[,5], ss[,4], fun, na.rm=na.rm)
 					cells <- as.numeric(rownames(v))
 					if (nres > 1) {
 						v <- as.matrix(v)
-						v = t(apply(v, 1, function(x) x[[1]]))  # Reshape the data if more than one value is returned by 'fun'
+						v <- t(apply(v, 1, function(x) x[[1]]))  # Reshape the data if more than one value is returned by 'fun'
 						d[cells, ] <- v
 					} else {
 						d[cells] <- v
@@ -170,21 +165,15 @@
 		
 	} else {
 	
-		if (ncols > 1) {
-			v <- aggregate(field, list(cells), fun, na.rm=na.rm)
-			cells <- as.numeric(v[,1])
-			v <- as.matrix(v)[,-1,drop=FALSE]
-		} else {
-			v <- tapply(field, cells, fun, na.rm=na.rm)
-			cells <- as.numeric(rownames(v))
-			v <- as.matrix(v)
-		}
+		v <- aggregate(field, list(cells), fun, na.rm=na.rm)
+		cells <- as.numeric(v[,1])
+		v <- as.matrix(v)[,-1,drop=FALSE]
 		
 		if(class(v[1]) == "list") {
-			v = t(apply(v, 1, function(x) x[[1]]))  # Reshape the data if more than one value is returned by 'fun'
+			v <- t(apply(v, 1, function(x) x[[1]]))  # Reshape the data if more than one value is returned by 'fun'
 		}
 
-		if (dim(v)[2] > 1) { 
+		if (ncol(v) > 1) { 
 			vv <- matrix(background, nrow=ncell(rs), ncol=dim(v)[2])
 			vv[cells, ] <- v
 		    rs <- brick(rs)  #  return a'RasterBrick'
@@ -228,4 +217,3 @@
 	}
 	return(rs)	
 }
-
