@@ -420,7 +420,7 @@ function(object, v, cell, band) {
 	if (setminmax) {	
 		b <- new("GDALRasterBand", gdal, band)
 		statistics <- c(object@data@min, object@data@max, NA, NA)
-		.gd_SetStatistics(b, statistics)
+		rgdal:::.gd_SetStatistics(b, statistics)
 	}
 
 	return(object)
